@@ -25,6 +25,8 @@ class AuthMiddleware(MiddlewareMixin):
         path = request.path
         tenant = AuthTenant.objects.filter(account=account).first()
         if tenant:
+            if tenant.account == 'admin':
+                return True
             permission = AuthPermission.objects.filter(action=method, source_id=path).first()
             if permission:
                 role_permissions = AuthRolePermissions.objects.filter(permission_id=permission.name).first()
